# Why don't you check to see if the message is plaintext before trying to decrypt anything?
It is assumed that if the user uses Ciphey, the message is not plaintext. If the message is plaintext, it will be found in Caesar Cipher with a shift of 0 (or 26).
